@@ -8,7 +8,7 @@ from collections import namedtuple
 import pickle
 import types as build_in_types
 
-
+__version__ = "0.9.2"
 
 class EventCollector:
     _submit_collector = {}
@@ -284,11 +284,13 @@ class TelebotForms:
         parse_mode = None
         if form.form_title:
             parse_mode = "Markdown"
+        self.bot.send_message(user_id,text)
         msg = self.bot.send_message(user_id,text,reply_markup=keyboard,parse_mode=parse_mode,disable_web_page_preview=True)
         form.last_msg_id = msg.message_id
         self.fsm.set_state(int(user_id),idle_state,life_time = settings["LIFE_TIME"],form=form._form_dumps())
         return msg
 
+
     def callback_events(self,call):
         form_status = self.fsm.check_already_form(int(call.from_user.id))
         if not form_status:
